#!/bin/bash


intfName=$1
netname=passthrough_$intfName


showHelp ()
{
    echo ""
    echo "    Usage:   $0  <interface_name>"
    echo ""
    echo "             example:     $0 eth15"
    echo ""
    echo "List of populated/available interfaces:"
    echo ""
    /home/catapult/vm/utils/showSlotInfo.sh
}

createPassthroughNetwork ()
{
    local tmpnet=/tmp/$netname.xml

    # Find out if this pasthrough network already exists
    if [[ -f /etc/libvirt/qemu/networks/$netname.xml ]]; then
        #local netStatus=`sudo virsh net-info $netname >/dev/null 2>&1`
        local netStatus=`sudo virsh net-info $netname`
        if [[ $netStatus == *"UUID:"* ]]; then
            echo "Keep existing $netname network ..."
            return 0
        fi
    fi

    echo "Create $netname network..."

    # Generate the xml file
    sudo rm -f $tmpnet
    echo "" > $tmpnet
    echo "<network>" >> $tmpnet
    echo "  <name>$netname</name>" >> $tmpnet
    echo "  <forward dev='$intfName' mode='passthrough'>" >> $tmpnet
    echo "    <interface dev='$intfName'/>" >> $tmpnet
    echo "  </forward>" >> $tmpnet
    echo "</network>" >> $tmpnet

    # Create the new passthrough
    sudo virsh net-define $tmpnet  >/dev/null 2>&1
    sudo virsh net-autostart $netname  >/dev/null 2>&1
}


if [[ "$#" -ne 1 ]]; then
    showHelp
    exit 1
fi

if [[ $(/home/catapult/vm/utils/showSlotInfo.sh | grep $intfName) == "" ]]; then
        echo "    Invalid interface ($intfName)"
        echo "    valid interfaces to select from:"
        /home/catapult/vm/utils/showSlotInfo.sh
        exit 1
fi

# Create the passthrough network
createPassthroughNetwork

if [[ "$?" -ne 0 ]]; then
    echo "Failed to create passthrough network with interface: $intfName"
    exit 1
else
    echo "Network $netname ready"
fi


exit 0



