#!/bin/bash


showHelp() {
    echo "$0 [-f] < dhcp | <ip> <mask> >"
    echo "    options:"
    echo "        -f    force new configuration"
    echo ""
    echo "    example:    $0 dhcp"
    echo "                $0 -f 10.15.20.25 255.255.255.0"
    echo ""
}

function isValidIp()
{
    local  ip=$1
    local  stat=1

    if [[ $ip =~ ^[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}$ ]]; then
        OIFS=$IFS
        IFS='.'
        ip=($ip)
        IFS=$OIFS
        [[ ${ip[0]} -le 255 && ${ip[1]} -le 255 \
            && ${ip[2]} -le 255 && ${ip[3]} -le 255 ]]
        stat=$?
    fi
    return $stat
}

force=0
dhcp=0
staticIP=0
mask=255.255.255.0
failConfig=0
ixInterfaceFile=/etc/network/interfaces.d/ixInterfaces
interfaceFile=/etc/network/interfaces
tempInterfaceFile=${interfaceFile}.temp


for argval in "$@"
do
    if [ $argval = "-f" ]; then
        echo "force option selected"
        force=1
        continue
    fi

    if [ $argval = "dhcp" ]; then
        echo "dhcp selected"
        dhcp=1
        break
    fi

    if [ $staticIP = 0 ]; then
        staticIP=$argval
        if isValidIp $staticIP; then
            echo "static IP ($staticIP) is valid"
        else
            echo "static IP ($staticIP) is INVALID"
            failConfig=1
        fi
        continue
    fi

    if [ $mask = 0 ]; then
        mask=$argval
        if isValidIp $mask; then
            echo "mask ($mask) is valid"
        else
            echo "mask ($mask) is INVALID"
            failConfig=1
        fi
        continue
    fi
done

if [ $dhcp = 0 ] && [ $staticIP = 0 ]; then
    failConfig=1
fi

if [ $failConfig = 1 ]; then
    showHelp
    exit 1
fi

if [ $dhcp = 0 ] && [ $staticIP = 0 ]; then
    showHelp
    exit 1
fi

if [[ -e $interfaceFile ]]; then
    if [ $force = 0 ]; then
        while IFS='' read -r line || [[ -n "$line" ]]; do
            if [[ $line == *"br0"* ]]; then
                echo "Not changing network, as network already configured and force option not selected"
                exit 1
            fi
        done < "$interfaceFile"
    fi
fi

cp $interfaceFile ${interfaceFile}.bak 
echo "#"                           >  $tempInterfaceFile
echo "auto eth0"                   >> $tempInterfaceFile
echo "iface eth0 inet manual"      >> $tempInterfaceFile
echo ""                            >> $tempInterfaceFile
echo "auto br0"                    >> $tempInterfaceFile

if [ $dhcp = 1 ]; then
    echo "iface br0 inet dhcp"     >> $tempInterfaceFile
else
    echo "iface br0 inet static"   >> $tempInterfaceFile
    echo "    address $staticIP"   >> $tempInterfaceFile
    echo "    netmask $mask"       >> $tempInterfaceFile
fi

echo "    bridge_ports eth0"       >> $tempInterfaceFile
echo "    bridge_stp off"          >> $tempInterfaceFile
echo "    bridge_fd 0"             >> $tempInterfaceFile
echo "    bridge_maxwait 0"        >> $tempInterfaceFile

if [ -f $ixInterfaceFile ]; then
    echo "IxInterfaces exists"
    echo ""                        >> $tempInterfaceFile
    echo "source $ixInterfaceFile" >> $tempInterfaceFile
fi

echo ""                            >> $tempInterfaceFile


mv -f $tempInterfaceFile $interfaceFile

echo "Done, changes will take effect after the next network restart"
