#!/bin/bash

showHelp()
{
    echo "Usage: $0 [10G|25G]"
    echo " lists the name and slot location for 10G/25G interfaces"
}


intfName=""
intfSpeed=""
intfPosition=""
requestedSpeed=""


if [[ "$#" -eq 1 ]]; then
    requestedSpeed=$1

    if [[ $requestedSpeed != "10G" ]] && [[ $requestedSpeed != "25G" ]]; then
        showHelp
        exit 1
    fi
fi


GetPciSlotInfo ()
{
    local refPciAddr=$1
    local localPciAddr

    IFS=$'\n'
    set -f
    for line in $ifList; do
        intfName=`echo $line | cut -d' ' -f3`
        localPciAddr=`echo $line | cut -d' ' -f1`
        localPciAddr=${localPciAddr:4}

        if [[ $localPciAddr == $refPciAddr ]]; then
            # Must be a 10G or 25G interface
            if [[ $line == *"10-Gigabit"* ]]; then
                intfSpeed="10G"
            elif [[ $line == *"MT27710"* ]]; then
                intfSpeed="25G"
            else
            set +f
            unset IFS
                return 1
            fi

            eval _ifName=`echo $line | cut -d' ' -f3`
            if [[ `cut --complement -d "." -f 1 <<< "$localPciAddr"` == "1" ]]; then
                intfPosition="bottom"
            else
                intfPosition="top"
            fi
        
        set +f
        unset IFS
        return 0
        fi
    done

    set +f
    unset IFS
    return 1
}

ifList=`sudo lshw -c network -businfo | grep "pci@"`


printf "\n  %-12s %-6s %-11s %-8s %-21s %-16s \n" "Name" "Slot" "Position" "Speed" "HW-Address" "PCI-Address"
printf "%-82s\n" "  ===========================================================================" 

for slot in {1..6}; do
    intfName=""
    intfSpeed=""
    intfPosition=""
    macAddr=""

    slotInUse="no"
    dmiInfo=`sudo dmidecode -t 9 | grep -B2 -A10 SLOT$slot`
    while IFS='' read -r line; do
        if [[ "$line" == *"In Use"* ]]; then
            slotInUse="yes"
            continue
        fi
        if [[ "$slotInUse" == "yes" ]]; then
            if [[ "$line" == *"Bus Address"* ]]; then
                slotPciAddr=`cut --complement -d ":" -f 1 <<< "$line" | xargs`
                GetPciSlotInfo $slotPciAddr $intfName $intfSpeed $intfPosition

                if [[ $intfName != "" ]]; then 
                    if [[ $requestedSpeed == "" ]] || [[ $intfSpeed == $requestedSpeed ]]; then
                        macAddr=`ip link show $intfName | grep "link/ether" | awk '{$1=$1};1' | cut -d' ' -f 2`
                        printf "  %-12s %-6s %-11s %-8s %-21s %-16s \n" "$intfName" "$slot" "$intfPosition" "$intfSpeed" "$macAddr" "$slotPciAddr"
                    fi
                fi
                slotPciAddr=${slotPciAddr/.0/.1}
                GetPciSlotInfo $slotPciAddr $intfName $intfSpeed $intfPosition
                if [[ $intfName != "" ]]; then
                    if [[ $requestedSpeed == "" ]] || [[ $intfSpeed == $requestedSpeed ]]; then
                        macAddr=`ip link show $intfName | grep "link/ether" | awk '{$1=$1};1' | cut -d' ' -f 2`
                        printf "  %-12s %-6s %-11s %-8s %-21s %-16s \n" "$intfName" "$slot" "$intfPosition" "$intfSpeed" "$macAddr" "$slotPciAddr"
                    fi
                fi
            fi
        fi
    done < <(printf '%s\n' "$dmiInfo")
done



